[![Build Status](https://travis-ci.com/SUSE-Enceladus/public-cloud-info-client.svg?branch=master)](https://travis-ci.com/SUSE-Enceladus/public-cloud-info-client)

pint
====

pint (Public Cloud INformation Tracker) is a command line client to access
the REST API provided by the SUSE Public Cloud Information Service. The
information service provides data about the images SUSE publishes in various
public cloud frameworks (Amazon, Google, Microsoft) as well as the
servers that make up the SUSE maintained and operated update infrastructure
in those frameworks.
